==> vcs-impl-222.4167.29-sources.jar: com/intellij/openapi/vcs/VcsFileListenerContextHelperImpl.java <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.openapi.vcs;

import com.intellij.openapi.util.SystemInfo;
import com.intellij.openapi.vcs.impl.projectlevelman.RecursiveFilePathSet;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

public class VcsFileListenerContextHelperImpl implements VcsFileListenerContextHelper {
  private final Object LOCK = new Object();
  private final Set<FilePath> myIgnoredDeleted = new HashSet<>();
  private final Set<FilePath> myIgnoredAdded = new HashSet<>();
  private final RecursiveFilePathSet myIgnoredAddedRecursive = new RecursiveFilePathSet(SystemInfo.isFileSystemCaseSensitive);

  @Override
  public void ignoreDeleted(@NotNull Collection<FilePath> filePath) {
    synchronized (LOCK) {
      myIgnoredDeleted.addAll(filePath);
    }
  }

  @Override
  public boolean isDeletionIgnored(@NotNull FilePath filePath) {
    synchronized (LOCK) {
      return myIgnoredDeleted.contains(filePath);
    }
  }

  @Override
  public void ignoreAdded(@NotNull Collection<FilePath> filePaths) {
    synchronized (LOCK) {
      myIgnoredAdded.addAll(filePaths);
    }
  }

  @Override
  public void ignoreAddedRecursive(@NotNull Collection<FilePath> filePaths) {
    synchronized (LOCK) {
      myIgnoredAddedRecursive.addAll(filePaths);
    }
  }

  @Override
  public boolean isAdditionIgnored(@NotNull FilePath filePath) {
    synchronized (LOCK) {
      return myIgnoredAdded.contains(filePath) ||
             myIgnoredAddedRecursive.hasAncestor(filePath);
    }
  }

  @Override
  public void clearContext() {
    synchronized (LOCK) {
      myIgnoredAdded.clear();
      myIgnoredAddedRecursive.clear();
      myIgnoredDeleted.clear();
    }
  }

  @Override
  public boolean isAdditionContextEmpty() {
    synchronized (LOCK) {
      return myIgnoredAdded.isEmpty() && myIgnoredAddedRecursive.isEmpty();
    }
  }

  @Override
  public boolean isDeletionContextEmpty() {
    synchronized (LOCK) {
      return myIgnoredDeleted.isEmpty();
    }
  }
}

==> vcs-impl-232.9921.47-sources.jar: com/intellij/openapi/vcs/VcsFileListenerContextHelperImpl.java <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.openapi.vcs;

import com.intellij.openapi.util.SystemInfo;
import com.intellij.openapi.vcs.impl.projectlevelman.RecursiveFilePathSet;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

public class VcsFileListenerContextHelperImpl implements VcsFileListenerContextHelper {
  private final Object LOCK = new Object();
  private final Set<FilePath> myIgnoredDeleted = new HashSet<>();
  private final Set<FilePath> myIgnoredAdded = new HashSet<>();
  private final RecursiveFilePathSet myIgnoredAddedRecursive = new RecursiveFilePathSet(SystemInfo.isFileSystemCaseSensitive);

  @Override
  public void ignoreDeleted(@NotNull Collection<? extends FilePath> filePath) {
    synchronized (LOCK) {
      myIgnoredDeleted.addAll(filePath);
    }
  }

  @Override
  public boolean isDeletionIgnored(@NotNull FilePath filePath) {
    synchronized (LOCK) {
      return myIgnoredDeleted.contains(filePath);
    }
  }

  @Override
  public void ignoreAdded(@NotNull Collection<? extends FilePath> filePaths) {
    synchronized (LOCK) {
      myIgnoredAdded.addAll(filePaths);
    }
  }

  @Override
  public void ignoreAddedRecursive(@NotNull Collection<? extends FilePath> filePaths) {
    synchronized (LOCK) {
      myIgnoredAddedRecursive.addAll(filePaths);
    }
  }

  @Override
  public boolean isAdditionIgnored(@NotNull FilePath filePath) {
    synchronized (LOCK) {
      return myIgnoredAdded.contains(filePath) ||
             myIgnoredAddedRecursive.hasAncestor(filePath);
    }
  }

  @Override
  public void clearContext() {
    synchronized (LOCK) {
      myIgnoredAdded.clear();
      myIgnoredAddedRecursive.clear();
      myIgnoredDeleted.clear();
    }
  }

  @Override
  public boolean isAdditionContextEmpty() {
    synchronized (LOCK) {
      return myIgnoredAdded.isEmpty() && myIgnoredAddedRecursive.isEmpty();
    }
  }

  @Override
  public boolean isDeletionContextEmpty() {
    synchronized (LOCK) {
      return myIgnoredDeleted.isEmpty();
    }
  }
}
